@@ -5,7 +5,7 @@ use strict;
 
 # ABSTRACT: A collection of handy Perl::Critic policies
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 1; # End of Perl::Critic::RENEEB
@@ -22,7 +22,7 @@ Perl::Critic::RENEEB - A collection of handy Perl::Critic policies
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -38,6 +38,10 @@ The rules included with the Perl::Critic::RENEEB group include:
 I use split with regular expressions regularly, but I don't want to use the x-modifier there. So
 I wrote this policy to check all regular expressions in my programs but those used as a parameter to split.
 
+=head2 L<Perl::Critic::Policy::Reneeb::ProhibitBlockEval>
+
+Use C<try{...}> from L<Try::Tiny|https://metacpan.org/pod/Try::Tiny> instead of C<eval{...}>.
+
 =head1 AUTHOR
 
 Renee Baecker <reneeb@cpan.org>
